import pytest

from zimran.logging.exceptions import InvalidEnvironmentError
from zimran.logging.utils import _get_sample_rate


def test_get_sample_rate() -> None:
    assert _get_sample_rate('production') == 0.2
    assert _get_sample_rate('staging') == 1

    with pytest.raises(InvalidEnvironmentError):
        _get_sample_rate('development')



import sys

from loguru import logger
from sentry_sdk import init

from zimran.logging.exceptions import InvalidEnvironmentError


def _get_sample_rate(environment: str) -> float:
    if environment == 'production':
        return 0.2

    if environment == 'staging':
        return 1

    raise InvalidEnvironmentError(environment)


def setup_logger(debug: bool) -> None:
    logger.remove()

    if debug:
        logger.add(sys.stdout, level='DEBUG')
    else:
        logger.add(sys.stdout, level='INFO', serialize=True)


def setup_sentry(dsn: str, environment: str, **kwargs) -> None:
    try:
        sample_rate = _get_sample_rate(environment)
    except InvalidEnvironmentError:
        return

    init(dsn=dsn, environment=environment, sample_rate=sample_rate, **kwargs)



from os import environ

from setuptools import find_namespace_packages, setup

with open('README.md', 'r', encoding='utf-8') as file:
    long_description = file.read()

setup(
    name='zimran-logging',
    version=environ['GITHUB_REF_NAME'],
    description='Loguru, Sentry based logging for FastAPI services',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=find_namespace_packages(include=['zimran.*']),
    install_requires=['loguru', 'sentry-sdk[fastapi,loguru]'],
    python_requires='>=3.10',
    zip_file=False,
)
